@@ -80,24 +80,3 @@ function(results, object) {
   }
   res
 }
-
-# ------------------------------------------------------------------------------
-# nocov start
-
-utils::globalVariables(
-  c('.', '.label', '.pred', '.row', 'data', 'engine', 'engine2', 'group',
-    'lab', 'original', 'predicted_label', 'prediction', 'value', 'type',
-    "neighbors", ".submodels", "has_submodel", "max_neighbor", "max_penalty",
-    "max_terms", "max_tree", "model", "name", "num_terms", "penalty", "trees",
-    "sub_neighbors", ".pred_class", "x", "y", "predictor_indicators",
-    "compute_intercept", "remove_intercept", "estimate", "term",
-    "call_info", "component", "component_id", "func", "tunable", "label",
-    "pkg", ".order", "item", "tunable", "has_ext"
-   )
-)
-
-release_bullets <- function() {
-  c("Run `knit_engine_docs()` and `devtools::document()` to update docs")
-}
-
-# nocov end
