@@ -2,6 +2,7 @@ set_new_model("boost_tree")
 
 set_model_mode("boost_tree", "classification")
 set_model_mode("boost_tree", "regression")
+set_model_mode("boost_tree", "censored regression")
 
 # ------------------------------------------------------------------------------
 
@@ -216,7 +217,7 @@ set_pred(
 # ------------------------------------------------------------------------------
 
 set_model_engine("boost_tree", "classification", "C5.0")
-set_dependency("boost_tree", "C5.0", "C50")
+set_dependency("boost_tree", "C5.0", "C50", mode = "classification")
 
 set_model_arg(
   model = "boost_tree",
