@@ -1,3 +1,6 @@
+#' @importFrom ggplot2 autoplot
+#' @export
+ggplot2::autoplot
 
 #' @importFrom magrittr %>%
 #' @export
@@ -34,3 +37,15 @@ hardhat::extract_spec_parsnip
 #' @importFrom hardhat extract_fit_engine
 #' @export
 hardhat::extract_fit_engine
+
+#' @importFrom hardhat extract_parameter_set_dials
+#' @export
+hardhat::extract_parameter_set_dials
+
+#' @importFrom hardhat extract_parameter_dials
+#' @export
+hardhat::extract_parameter_dials
+
+#' @importFrom hardhat tune
+#' @export
+hardhat::tune
